pt_blk_set_image

Function pt_blk_set_image 

pub unsafe extern "C" fn pt_blk_set_image(
    decoder: *mut pt_block_decoder,
    image: *mut pt_image,
) -> c_int
Set the traced image.

Sets the image that @decoder uses for reading memory to @image. If @image is NULL, sets the image to @decoder’s default image.

Only one image can be active at any time.

Returns zero on success, a negative error code otherwise. Return -pte_invalid if @decoder is NULL.