pt_image_add_cached

Function pt_image_add_cached 

pub unsafe extern "C" fn pt_image_add_cached(
    image: *mut pt_image,
    iscache: *mut pt_image_section_cache,
    isid: c_int,
    asid: *const pt_asid,
) -> c_int
Add a section from an image section cache.

Add the section from @iscache identified by @isid in address space @asid.

Existing sections that would overlap with the new section will be shrunk or split.

Returns zero on success, a negative error code otherwise. Returns -pte_invalid if @image or @iscache is NULL. Returns -pte_bad_image if @iscache does not contain @isid.