pt_iscache_set_limit

Function pt_iscache_set_limit 

pub unsafe extern "C" fn pt_iscache_set_limit(
    iscache: *mut pt_image_section_cache,
    limit: u64,
) -> c_int
Set the image section cache limit.

Set the limit for a section cache in bytes. A non-zero limit will keep the least recently used sections mapped until the limit is reached. A limit of zero disables caching.

Returns zero on success, a negative pt_error_code otherwise. Returns -pte_invalid if @iscache is NULL.